<?php
/*
Plugin Name: Simple URL Shortenr
Plugin URI: http://www.artiss.co.uk/simple-url-shortener
Description: Shorten a URL using one of many shortening services 
Version: 1.0
Author: David Artiss
Author URI: http://www.artiss.co.uk
*/
function simple_url_shortener($url,$service_name) {

    // Check URL - if blank use URL of current post/page
    if ($url=="") {$url=get_permalink($post->ID);}
    
    // Build array of services    
    $shortening_services = build_services_array();

    // Get the URL of the required shortening service
    // If the service is not found, default to the full length URL
    $service_url = $shortening_services[$service_name];
    if ($service_url=="") {
        $shorturl=$url;
    } else {
        // Access the service API and get the shortened URL
        $shorturl = simple_get_file($service_url.$url);

        // If no URL is returned, default it to the full length URL
        if ($shorturl=="") {$shorturl=$url;}
    }

    return $shorturl;
}

// Function to get a file using CURL or alternative

function simple_get_file($filein) {

    if (in_array('curl', get_loaded_extensions())===true) {
        $cURL = curl_init();
        curl_setopt($cURL,CURLOPT_URL,$filein);
        curl_setopt($cURL,CURLOPT_RETURNTRANSFER,1);
        $fileout=curl_exec($cURL);
        curl_close($cURL);
    } else {
        if (strtolower(ini_get('allow_url_fopen'))!="off") {
            $fileout=file_get_contents($filein);
        } else {
            $fileout="";
        }
    }

    return $fileout;
}

// Function to validate a URL shortening service

function validate_url_shortener($validate_text,$validate_mask) {

    // Ensure that the service tag is in the mask
    if (strpos($validate_mask,"{service}")===false) {$validate_mask="{service}";}
    
    // Build array of services    
    $shortening_services = build_services_array();    

    // Read through each service name and attempt to find it in the text,
    // applying any masks
    foreach($shortening_services as $key => $value) {
        $find_in_text = str_replace('{service}',$key,$validate_mask);
        if (strpos($validate_text,$find_in_text)!==false) {$shorturl=$key;}
    }

    return $shorturl;
}

// Function to build array of URL shortening services

function build_services_array() {

    $service=array( "a.gd"=>"http://a.gd/?module=ShortURL&file=Add&mode=API&url=",
                    "a.nf"=>"http://a.nf/?module=ShortURL&file=Add&mode=API&url=",
                    "buk.me"=>"http://buk.me/api.php?url=",
                    "bit.ly"=>"http://bit.ly/api?url=",
                    "chilp.it"=>"http://chilp.it/api.php?url=",
                    "cli.gs"=>"http://cli.gs/api/v1/cligs/create?url=",
                    "fwd4.me"=>"http://api.fwd4.me/?url=",
                    "hex.io"=>"http://hex.io/api-create.php?url=",
                    "is.gd"=>"http://is.gd/api.php?longurl=",
                    "idek.net"=>"http://idek.net/shorten/?idek-api=true&idek-url=",
                    "j.mp"=>"http://bit.ly/api?url=",
                    "kissa.be"=>"http://kissa.be/api/shortener/url?content=",
                    "pic.gd"=>"http://pic.gd/?module=ShortURL&file=Add&mode=API&url=",
                    "r.im"=>"http://r.im/api/index.cfm?long_url=",
                    "safe.mn"=>"http://safe.mn/api/?url=",
                    "sai.ly"=>"http://www.sai.ly/new.txt?href=",
                    "short.to"=>"http://short.to/s.txt?url=",
                    "sl.ly"=>"http://sl.ly/?module=ShortURL&file=Add&mode=API&url=",
                    "su.pr"=>"http://su.pr/api?url=",
                    "tinyurl"=>"http://tinyurl.com/api-create.php?url=",
                    "tr.im"=>"http://api.tr.im/api/trim_simple?url=",
                    "u.nu"=>"http://u.nu/unu-api-simple?url=",
                    "unfake.it"=>"http://unfake.it/?a=api&url=",
                    "vtc.es"=>"http://vtc.es/create.php?url=",
                    "xr.com"=>"http://api.xr.com/api?link=",
                    "zz.gd"=>"http://zz.gd/api-create.php?url=");

    return $service;
}
?>